@@ -12,8 +12,7 @@ from transformers import (PreTrainedTokenizerBase,
                           PrinterCallback,
                           EarlyStoppingCallback,
                           RobertaForSequenceClassification,
-                          RobertaForTokenClassification,
-                          set_seed)
+                          RobertaForTokenClassification)
 from typing import Dict, Optional, Tuple, List, Any
 import numpy as np
 import requests
@@ -26,6 +25,7 @@ from functools import partial
 import gc
 import logging
 import re
+import random
 
 from .utils import (MODEL_CLASSES, is_module_installed, InvalidBenchmark,
                     TwolabelTrainer)
@@ -452,10 +452,15 @@ class BaseBenchmark(ABC):
 
             # Set the maximal length of the tokenizer to the model's maximal
             # length. This is required for proper truncation
-            try:
-                tokenizer.model_max_length = config.max_position_embeddings
-            except AttributeError:
-                pass
+            if (not hasattr(tokenizer, 'model_max_length') or
+                    tokenizer.model_max_length > 1_000):
+
+                if hasattr(tokenizer, 'max_model_input_sizes'):
+                    all_max_lengths = tokenizer.max_model_input_sizes.values()
+                    min_max_length = min(list(all_max_lengths))
+                    tokenizer.model_max_length = min_max_length
+                else:
+                    tokenizer.model_max_length = 512
 
             return dict(model=model, tokenizer=tokenizer)
 
@@ -694,6 +699,10 @@ class BaseBenchmark(ABC):
         # Load the dataset
         train, test = self._load_data()
 
+        # Set platform-independent random seeds
+        random.seed(4242)
+        np.random.seed(4242)
+
         # Initialise random number generator
         rng = np.random.default_rng(4242)
 
@@ -702,8 +711,16 @@ class BaseBenchmark(ABC):
 
         if framework in ['pytorch', 'tensorflow', 'jax']:
 
-            # Set random seed
-            set_seed(4242)
+            # Set platform-dependent random seeds
+            if framework == 'pytorch':
+                import torch
+                torch.manual_seed(4242)
+                torch.cuda.manual_seed_all(4242)
+                torch.backends.cudnn.benchmark = False
+
+            elif framework == 'tensorflow':
+                import tensorflow as tf
+                tf.random.set_seed(4242)
 
             # Extract the model and tokenizer
             model = model_dict['model']
@@ -840,12 +857,13 @@ class BaseBenchmark(ABC):
 
                         # Garbage collection, to avoid memory issues
                         try:
-                            del model, model_dict
+                            del model
                         except UnboundLocalError:
-                            try:
-                                del model
-                            except UnboundLocalError:
-                                pass
+                            pass
+                        try:
+                            del model_dict
+                        except UnboundLocalError:
+                            pass
                         gc.collect()
 
             self._log_metrics(metrics, model_id=model_id, finetuned=finetune)
