@@ -74,10 +74,22 @@ class Benchmark:
         # updated as more models are benchmarked
         self.benchmark_results = defaultdict(dict)
 
-        # Initialise the list of all benchmarks, along with their variable
-        # names and the more descriptive names
-        params = dict(verbose=verbose,
-                      evaluate_train=evaluate_train)
+        # Set logging level based on verbosity
+        if verbose:
+            logging_level = logging.DEBUG
+        else:
+            logging_level = logging.INFO
+        logger.setLevel(logging_level)
+
+    def _update_benchmarks(self, **params):
+        '''Updates the internal list of all benchmarks.
+
+        This list will be stored in the `_benchmarks` variable.
+
+        Args:
+            params:
+                Dictionary of benchmark parameters.
+        '''
         self._benchmarks = [
             ('dane', 'DaNE with MISC tags', DaneBenchmark(**params)),
             ('dane-no-misc', 'DaNE without MISC tags',
@@ -95,13 +107,6 @@ class Benchmark:
             ('lcc2', 'LCC2', Lcc2Benchmark(**params))
         ]
 
-        # Set logging level based on verbosity
-        if verbose:
-            logging_level = logging.DEBUG
-        else:
-            logging_level = logging.INFO
-        logger.setLevel(logging_level)
-
     @staticmethod
     def _get_model_ids(language: Optional[str] = None,
                        task: Optional[str] = None) -> List[str]:
@@ -121,7 +126,7 @@ class Benchmark:
         # Set GET request parameter values
         params = dict()
         if language is not None:
-            params['filter'] = language
+            params['language'] = language
         if task is not None:
             params['pipeline_tag'] = task
 
@@ -139,21 +144,6 @@ class Benchmark:
                      header.get('title') is not None and
                      'items-center' in header['class']]
 
-        # There might still be models in the list, which is *not* in the given
-        # language, but still ended up in the search results, as the
-        # HuggingFace Hub only searches generally for the language code. We
-        # filter these out here.
-        for model_id in model_ids:
-            model_url = f'https://huggingface.co/{model_id}'
-            html = requests.get(model_url).text
-            soup = BeautifulSoup(html, 'html.parser')
-            a_tags_with_class = [a for a in soup.find_all('a')
-                                 if a.get('class') is not None]
-            languages = [a['tag-id'] for a in a_tags_with_class
-                         if 'tag-green' in a['class']]
-            if language not in languages:
-                model_ids.remove(model_id)
-
         return model_ids
 
     def _get_model_lists(self,
@@ -299,6 +289,9 @@ class Benchmark:
         if verbose is None:
             verbose = self.verbose
 
+        # Update benchmark list
+        self._update_benchmarks(evaluate_train=evaluate_train, verbose=verbose)
+
         # Ensure that `language` is a list
         if language == 'all':
             languages = [None]
